# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.rbac_api import RbacApi


class TestRbacApi(unittest.TestCase):
    """RbacApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RbacApi()

    def tearDown(self) -> None:
        pass

    def test_rbac_initial_permissions_create(self) -> None:
        """Test case for rbac_initial_permissions_create

        """
        pass

    def test_rbac_initial_permissions_destroy(self) -> None:
        """Test case for rbac_initial_permissions_destroy

        """
        pass

    def test_rbac_initial_permissions_list(self) -> None:
        """Test case for rbac_initial_permissions_list

        """
        pass

    def test_rbac_initial_permissions_partial_update(self) -> None:
        """Test case for rbac_initial_permissions_partial_update

        """
        pass

    def test_rbac_initial_permissions_retrieve(self) -> None:
        """Test case for rbac_initial_permissions_retrieve

        """
        pass

    def test_rbac_initial_permissions_update(self) -> None:
        """Test case for rbac_initial_permissions_update

        """
        pass

    def test_rbac_initial_permissions_used_by_list(self) -> None:
        """Test case for rbac_initial_permissions_used_by_list

        """
        pass

    def test_rbac_permissions_assigned_by_roles_assign(self) -> None:
        """Test case for rbac_permissions_assigned_by_roles_assign

        """
        pass

    def test_rbac_permissions_assigned_by_roles_list(self) -> None:
        """Test case for rbac_permissions_assigned_by_roles_list

        """
        pass

    def test_rbac_permissions_assigned_by_roles_unassign_partial_update(self) -> None:
        """Test case for rbac_permissions_assigned_by_roles_unassign_partial_update

        """
        pass

    def test_rbac_permissions_assigned_by_users_assign(self) -> None:
        """Test case for rbac_permissions_assigned_by_users_assign

        """
        pass

    def test_rbac_permissions_assigned_by_users_list(self) -> None:
        """Test case for rbac_permissions_assigned_by_users_list

        """
        pass

    def test_rbac_permissions_assigned_by_users_unassign_partial_update(self) -> None:
        """Test case for rbac_permissions_assigned_by_users_unassign_partial_update

        """
        pass

    def test_rbac_permissions_list(self) -> None:
        """Test case for rbac_permissions_list

        """
        pass

    def test_rbac_permissions_retrieve(self) -> None:
        """Test case for rbac_permissions_retrieve

        """
        pass

    def test_rbac_permissions_roles_destroy(self) -> None:
        """Test case for rbac_permissions_roles_destroy

        """
        pass

    def test_rbac_permissions_roles_list(self) -> None:
        """Test case for rbac_permissions_roles_list

        """
        pass

    def test_rbac_permissions_roles_partial_update(self) -> None:
        """Test case for rbac_permissions_roles_partial_update

        """
        pass

    def test_rbac_permissions_roles_retrieve(self) -> None:
        """Test case for rbac_permissions_roles_retrieve

        """
        pass

    def test_rbac_permissions_roles_update(self) -> None:
        """Test case for rbac_permissions_roles_update

        """
        pass

    def test_rbac_permissions_users_destroy(self) -> None:
        """Test case for rbac_permissions_users_destroy

        """
        pass

    def test_rbac_permissions_users_list(self) -> None:
        """Test case for rbac_permissions_users_list

        """
        pass

    def test_rbac_permissions_users_partial_update(self) -> None:
        """Test case for rbac_permissions_users_partial_update

        """
        pass

    def test_rbac_permissions_users_retrieve(self) -> None:
        """Test case for rbac_permissions_users_retrieve

        """
        pass

    def test_rbac_permissions_users_update(self) -> None:
        """Test case for rbac_permissions_users_update

        """
        pass

    def test_rbac_roles_create(self) -> None:
        """Test case for rbac_roles_create

        """
        pass

    def test_rbac_roles_destroy(self) -> None:
        """Test case for rbac_roles_destroy

        """
        pass

    def test_rbac_roles_list(self) -> None:
        """Test case for rbac_roles_list

        """
        pass

    def test_rbac_roles_partial_update(self) -> None:
        """Test case for rbac_roles_partial_update

        """
        pass

    def test_rbac_roles_retrieve(self) -> None:
        """Test case for rbac_roles_retrieve

        """
        pass

    def test_rbac_roles_update(self) -> None:
        """Test case for rbac_roles_update

        """
        pass

    def test_rbac_roles_used_by_list(self) -> None:
        """Test case for rbac_roles_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
